function model = loadGRRules(model, file)
% Construct gene-protein association matrix from a spreadsheet, map GeneIDs
% to unique ECs in model.rxns as an edge graph
% input: struct model
% input: spreadsheet with EC numbers in the first column and associated
%   GeneIDs in subsequent columns
% output: struct model with fields model.myGenes and model.myGrRules
% note: not meant to work with built-in gene association functions of
%   Cobra Toolbox, may later adapt model.myGenes and model.grRules to
%   model.genes and model.rxnGeneMat respectively
% Carl Song, March 25, 2011

[num txt] = xlsread(file);
reactions = txt(:,1);
geneList = {};
for i = 1:length(model.rxns)
    row = find(ismember(reactions, model.rxns(i)));
    if ~numel(row)
        row = find(ismember(reactions, regexprep(model.rxns(i), '[a-z]', '')));
    end
    if numel(row)
        for column = 2:size(txt,2)
            gene = txt{row,column};            
            if gene
                k = find(ismember(geneList, gene));
                if k
                    grRules(i,k) = 1;
                else
                    geneList = [geneList, gene];
                    grRules(i,length(geneList)) = 1;
                end
            else
                if gene ~= ''
                    gene
                end
            end
        end
    else
        grRules(i,:) = 0;
    end
end

model.myGrRules = grRules;
model.myGenes = geneList;

end